==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/commons/util/URLDecodeUtil.java <==
package org.itscool.commons.util;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;

/**
 * UTF-8  Shift_JIS 
 * 킸ƒmꂽƂ܂񂪁AJava ł͓{Ȃǂ QoCgR[h
 * Ǘ̂ Unicode pĂ܂B 
 * 
 * vbgz[ɈˑȂR[h߂ɁA͔ɏdvȂƂłB 
 * AJava ̗͂LpF߂Ă܂󂢂A vbgtH[
 * ł͈ˑRƂ OS ɈˑZbggpĂ܂B 
 * 
 * Java  Java ƂāAStand Alone Application ƂĂAApplet Game Ƃ
 * gpꍇ͂̂łA HTTP Server ͂߂Ƃ Client/Server 
 * AvP[V\z鎞ɂ͂Ȃ̍lKvłB 
 * 
 *  Client uEUłꍇA{iɊւ炸 ASCI R[hȊǑj 
 * URLEncoding ƂŁA GR[h܂B
 *  ASCI ŕ\ȂϊAASCI őMƂ@łB 
 * 
 * URLEncoding ̏ڍׂ͂ĂAJava ɂGR[fBO̒ӓ_܂
 * 
 * Java ɂ URLEncoding  
 * Java ł URLEncoding 邽߂炩߁AURLEncoder  URLDecoder Ƃ 
 * NX`Ă܂B
 * ꂪ Java ̃NXCu֗̕ȂƂŁA lbg[NvO~O
 * Kvȕ͑CuƂĒ񋟂Ă܂B 
 * 
 * AłB
 * 
 * Java yAƖAvP[V̊Jɂgn߂A J2SE 1.3  
 * 1.4 ւƃo[WオAURLEncoder ̎dlɎ኱̕ύX܂B 
 * 
 * yύX_z
 * 
 * EURLEncoding ɁAϊΏۂ̕Zbgwł悤ɂȂiRecomendj
 * EEncoding/Decoding ̕AW3C ̎dlɏ悤ɂȂB
 * EcB 
 * 
 * ́AQ_ڂvʉeNĂ܂̂łB
 * ł͂܂ŎgpĂGR[fBOƂ͉Ⴄ̂ł傤H 
 * 
 * Ⴆ΁A"eXg"Ƃ Shift_JIS GR[hƂ܂B
 * 
 * ܂AJava  URLEncoder ̃GR[hʂł́A
 * 
 * %83%65%83%58%83%67
 * 
 * ƂȂ܂AWeb uEUŃGR[hƁA
 * 
 * %83e%83X%83g
 * 
 * ƂȂ܂B҂̕ϊʂႢ܂ˁH@
 * 
 * ł͎gɂȂ܂B
 * 
 * Shift_JIS ̃GR[h̕኱ύXꂽʁÂ悤ȍق
 * 悤ɂȂ܂B
 * 
 * ܂ł Web uEUƓGR[fBÔłA J2SE 1.4 
 * QoCgR[h̎舵ɕύXłB 
 * 
 * ł́AUTF-8 ł͂ǂł傤B
 * J2SE API Document ɂ悤ɁA J2SE 1.4 ȍ~ł́AUnicode nȊO̕Zbg
 * ͌ʂۏ؂Ȃ悤łB ɏ]AUTF-8 ł̃R[fBO܂B
 * 
 * ŐVȖɂԂ܂B 
 * 
 * UTF-8 ɑΉuEUAɒ[ɏȂ̂łB\ł̂͑܂B
 *  UTF-8 ɂGR[fBOɑΉuEÚA܂B
 *  mFƂŁASafari 1.0AIE6.0 炢łBwǂ̓CvbgtH[
 *  ܂B Java Ȃ̂ɃvbgtH[ɈˑH@ƂvĂ܂܂B 
 *  
 *  iǋLFȂƁAIE6.0łAMacOSpWindowspł舵ɈႢ悤łB
 *  LinuxpuEUÃuEȖ݂lƁAuEU^Cvϐ
 *  荞ŃT[oőΉ̂͂ƂĂʓ|łˁj
 *  
 *  łB
 *  
 *  ǂ̂ƂNCAg{f[^󂯎邽߂ɂ Shift_JIS gp
 *  Ȃ̂łB
 *  ݕyĂwǂ̃uEUŁA 삪ۏ؂Ă̂ Shift_JIS Ȃ
 *  łB 
 *  ilȂAClient ̃vbgz[ɂ UTF-8  łȂ
 *  ̂ Shift_JIS pǂł傤cj 
*/
public class URLDecodeUtil{
	/**
	 * Shift_JIS fR[h  
	 * 
	 * uEUɂGR[hʂ́A
	 * 
	 * %83e%83X%83g
	 * 
	 * ċCÂƁA̓uEUɂ Shift_JIS GR[h́AQoCg
	 * ̂ ̃oCg Alpha Newmeric ŕ\ĂƂƂłB
	 * 
	 * ܂AQoCgڂ GR[hہAASCI R[h͈̔͂ɂ̂́A
	 * ̂܂܂̌`ŕ\Ă̂łB
	 * 
	 * 邱Ƃɂē]f[^ʂ炻ƂƂł傤B 
	 * Ȃɂ W3C ̐Ȏdlł͂ȂA ́iJava HsV̈j@A
	 * ft@NgX^_[hƂĈʂɎgpĂ܂B 
	 * 
	 * Pꕶ 'e' PUi\ƁA"65" ɂȂ܂ iX="58"Ag="67"B
	 * Java ɂGR[fBOʂƔrĂ݂ājB̗v̂ŕϊĂ
	 * Java łłGR[h`ɒu邱Ƃł܂B
	 * 
	 * Tv͂ȊłB
	 * 
	 * 񒆂ɃGXP[vĹƂA̎̂QShift_JIŜPڂ
	 * ƂɂȂ܂B
	 * 
	 * ̂Ƃ͉܂B
	 * Rڂ%łΓ܂B
	 * RڂłȂꍇA̕ASCIR[hPUi\Lɒ%ƈꏏɕ
	 * ɒǉ܂B
	 * 
	 * 2BYTEϊł܂B
	 * JԂƂɂShift_JISJava URLDecoderł`
	 * ϊ܂BRAׂẴGR[hʂ%Ăꍇł肠܂B
	 * 
	 *  URLDecoder NX decode() \bh̒ɋLq܂傤B
	 * I[oChȂAJava RuntimeZIPt@C𓀂Ȃ肵ĕҏW
	 * 悢Ǝv܂B
	 * 
	 * iCZX̖肪邩܂BBBj܂AURLDecodeʂ𐳋K
	 * 郁\bhƂĒǉLq̂ԊȒPƎv܂B
	 * 
	 * ̃WbNł́AGR[h@ł̕ɂ͉e^܂B
	 *  ͂ŕϊꂽʏʂ decode() ΁AShift_JIS fR[h
	 *  łB 
	 *  ԗ͋ZłAClient𐧌AύX邱Ƃl΂͂邩ɂ܂
	 *  
	 * @param s
	 * @param enc
	 * @return
	 * @throws UnsupportedEncodingException
	 */
	public static String decode(String s, String enc) 
	throws UnsupportedEncodingException{
		if (enc.compareTo("UTF-8") != 0) {
			StringBuffer tmp = new StringBuffer();
			char pc = 0;
			int j = 0;
			while (j < s.length()) {
				pc = s.charAt(j);
				if (pc == '%') {
					if (Integer.parseInt(s.substring(j + 1, j + 3), 16) < 0x81) {
						tmp.append(s.substring(j, j + 3));
						j += 3;
						continue;
					}
					tmp.append(s.substring(j, j + 3));
					j += 3;
					if ((pc = s.charAt(j)) == '%') {
						tmp.append(s.substring(j, j + 3));
						j += 3;
					} else {
						tmp.append('%');
						tmp.append(Integer.toHexString((int) pc));
						j++;
					}
				} else {
					tmp.append(pc);
					j++;
				}
			}
			s = tmp.toString();
			//numChars = s.length();
		}
		return URLDecoder.decode(s, enc);
	}
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/commons/util/URLDecodeUtil.java <==
package org.itscool.commons.util;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;

/**
 * UTF-8  Shift_JIS 
 * 킸ƒmꂽƂ܂񂪁AJava ł͓{Ȃǂ QoCgR[h
 * Ǘ̂ Unicode pĂ܂B 
 * 
 * vbgz[ɈˑȂR[h߂ɁA͔ɏdvȂƂłB 
 * AJava ̗͂LpF߂Ă܂󂢂A vbgtH[
 * ł͈ˑRƂ OS ɈˑZbggpĂ܂B 
 * 
 * Java  Java ƂāAStand Alone Application ƂĂAApplet Game Ƃ
 * gpꍇ͂̂łA HTTP Server ͂߂Ƃ Client/Server 
 * AvP[V\z鎞ɂ͂Ȃ̍lKvłB 
 * 
 *  Client uEUłꍇA{iɊւ炸 ASCI R[hȊǑj 
 * URLEncoding ƂŁA GR[h܂B
 *  ASCI ŕ\ȂϊAASCI őMƂ@łB 
 * 
 * URLEncoding ̏ڍׂ͂ĂAJava ɂGR[fBO̒ӓ_܂
 * 
 * Java ɂ URLEncoding  
 * Java ł URLEncoding 邽߂炩߁AURLEncoder  URLDecoder Ƃ 
 * NX`Ă܂B
 * ꂪ Java ̃NXCu֗̕ȂƂŁA lbg[NvO~O
 * Kvȕ͑CuƂĒ񋟂Ă܂B 
 * 
 * AłB
 * 
 * Java yAƖAvP[V̊Jɂgn߂A J2SE 1.3  
 * 1.4 ւƃo[WオAURLEncoder ̎dlɎ኱̕ύX܂B 
 * 
 * yύX_z
 * 
 * EURLEncoding ɁAϊΏۂ̕Zbgwł悤ɂȂiRecomendj
 * EEncoding/Decoding ̕AW3C ̎dlɏ悤ɂȂB
 * EcB 
 * 
 * ́AQ_ڂvʉeNĂ܂̂łB
 * ł͂܂ŎgpĂGR[fBOƂ͉Ⴄ̂ł傤H 
 * 
 * Ⴆ΁A"eXg"Ƃ Shift_JIS GR[hƂ܂B
 * 
 * ܂AJava  URLEncoder ̃GR[hʂł́A
 * 
 * %83%65%83%58%83%67
 * 
 * ƂȂ܂AWeb uEUŃGR[hƁA
 * 
 * %83e%83X%83g
 * 
 * ƂȂ܂B҂̕ϊʂႢ܂ˁH@
 * 
 * ł͎gɂȂ܂B
 * 
 * Shift_JIS ̃GR[h̕኱ύXꂽʁÂ悤ȍق
 * 悤ɂȂ܂B
 * 
 * ܂ł Web uEUƓGR[fBÔłA J2SE 1.4 
 * QoCgR[h̎舵ɕύXłB 
 * 
 * ł́AUTF-8 ł͂ǂł傤B
 * J2SE API Document ɂ悤ɁA J2SE 1.4 ȍ~ł́AUnicode nȊO̕Zbg
 * ͌ʂۏ؂Ȃ悤łB ɏ]AUTF-8 ł̃R[fBO܂B
 * 
 * ŐVȖɂԂ܂B 
 * 
 * UTF-8 ɑΉuEUAɒ[ɏȂ̂łB\ł̂͑܂B
 *  UTF-8 ɂGR[fBOɑΉuEÚA܂B
 *  mFƂŁASafari 1.0AIE6.0 炢łBwǂ̓CvbgtH[
 *  ܂B Java Ȃ̂ɃvbgtH[ɈˑH@ƂvĂ܂܂B 
 *  
 *  iǋLFȂƁAIE6.0łAMacOSpWindowspł舵ɈႢ悤łB
 *  LinuxpuEUÃuEȖ݂lƁAuEU^Cvϐ
 *  荞ŃT[oőΉ̂͂ƂĂʓ|łˁj
 *  
 *  łB
 *  
 *  ǂ̂ƂNCAg{f[^󂯎邽߂ɂ Shift_JIS gp
 *  Ȃ̂łB
 *  ݕyĂwǂ̃uEUŁA 삪ۏ؂Ă̂ Shift_JIS Ȃ
 *  łB 
 *  ilȂAClient ̃vbgz[ɂ UTF-8  łȂ
 *  ̂ Shift_JIS pǂł傤cj 
*/
public class URLDecodeUtil{
	/**
	 * Shift_JIS fR[h  
	 * 
	 * uEUɂGR[hʂ́A
	 * 
	 * %83e%83X%83g
	 * 
	 * ċCÂƁA̓uEUɂ Shift_JIS GR[h́AQoCg
	 * ̂ ̃oCg Alpha Newmeric ŕ\ĂƂƂłB
	 * 
	 * ܂AQoCgڂ GR[hہAASCI R[h͈̔͂ɂ̂́A
	 * ̂܂܂̌`ŕ\Ă̂łB
	 * 
	 * 邱Ƃɂē]f[^ʂ炻ƂƂł傤B 
	 * Ȃɂ W3C ̐Ȏdlł͂ȂA ́iJava HsV̈j@A
	 * ft@NgX^_[hƂĈʂɎgpĂ܂B 
	 * 
	 * Pꕶ 'e' PUi\ƁA"65" ɂȂ܂ iX="58"Ag="67"B
	 * Java ɂGR[fBOʂƔrĂ݂ājB̗v̂ŕϊĂ
	 * Java łłGR[h`ɒu邱Ƃł܂B
	 * 
	 * Tv͂ȊłB
	 * 
	 * 񒆂ɃGXP[vĹƂA̎̂QShift_JIŜPڂ
	 * ƂɂȂ܂B
	 * 
	 * ̂Ƃ͉܂B
	 * Rڂ%łΓ܂B
	 * RڂłȂꍇA̕ASCIR[hPUi\Lɒ%ƈꏏɕ
	 * ɒǉ܂B
	 * 
	 * 2BYTEϊł܂B
	 * JԂƂɂShift_JISJava URLDecoderł`
	 * ϊ܂BRAׂẴGR[hʂ%Ăꍇł肠܂B
	 * 
	 *  URLDecoder NX decode() \bh̒ɋLq܂傤B
	 * I[oChȂAJava RuntimeZIPt@C𓀂Ȃ肵ĕҏW
	 * 悢Ǝv܂B
	 * 
	 * iCZX̖肪邩܂BBBj܂AURLDecodeʂ𐳋K
	 * 郁\bhƂĒǉLq̂ԊȒPƎv܂B
	 * 
	 * ̃WbNł́AGR[h@ł̕ɂ͉e^܂B
	 *  ͂ŕϊꂽʏʂ decode() ΁AShift_JIS fR[h
	 *  łB 
	 *  ԗ͋ZłAClient𐧌AύX邱Ƃl΂͂邩ɂ܂
	 *  
	 * @param s
	 * @param enc
	 * @return
	 * @throws UnsupportedEncodingException
	 */
	public static String decode(String s, String enc) 
	throws UnsupportedEncodingException{
		if (enc.compareTo("UTF-8") != 0) {
			StringBuffer tmp = new StringBuffer();
			char pc = 0;
			int j = 0;
			while (j < s.length()) {
				pc = s.charAt(j);
				if (pc == '%') {
					if (Integer.parseInt(s.substring(j + 1, j + 3), 16) < 0x81) {
						tmp.append(s.substring(j, j + 3));
						j += 3;
						continue;
					}
					tmp.append(s.substring(j, j + 3));
					j += 3;
					if ((pc = s.charAt(j)) == '%') {
						tmp.append(s.substring(j, j + 3));
						j += 3;
					} else {
						tmp.append('%');
						tmp.append(Integer.toHexString((int) pc));
						j++;
					}
				} else {
					tmp.append(pc);
					j++;
				}
			}
			s = tmp.toString();
			//numChars = s.length();
		}
		return URLDecoder.decode(s, enc);
	}
	
	/**
     * NGXgp[^̃tB^s܂B
     * @param value
     * @return tB^̃p[^Ԃ܂
     */
    public static String filter(String value){
        if( value== null ){
            return "";
        }
        
        StringBuffer result = new StringBuffer();
        for( int i=0; i<value.length(); i++){
            switch( value.charAt(i)){
                case '<' :
                    result.append("&lt;");
                    break;
                case '>' :
                    result.append("&gt;");
                    break;
                case '&' :
                    result.append("&amp;");
                    break;
                case '"' :
                    result.append("&quot");
                    break;
                default :
                    result.append(value.charAt(i));
                    
            }
        }
        return result.toString();
    }
}
